@@ -121,6 +121,12 @@
                                 ]
                             },
                             "default": 1
+                        },
+                        {
+                            "key": "mixed_sort",
+                            "text": qsTranslate("GenerateSettingTranslate", "Mix sorting of files and folders"),
+                            "type": "checkbox",
+                            "default": false
                         }
                     ]
                 },
@@ -227,6 +233,12 @@
                             "type": "checkbox",
                             "default": false,
                             "hide": true
+                        },
+                        {
+                            "key": "audio_file_preview",
+                            "text": qsTranslate("GenerateSettingTranslate", "Music preview"),
+                            "type": "checkbox",
+                            "default": true
                         }
                     ]
                 },
