@@ -121,6 +121,12 @@
                                 ]
                             },
                             "default": 1
+                        },
+                        {
+                            "key": "mixed_sort",
+                            "text": qsTranslate("GenerateSettingTranslate", "Mix sorting of files and folders"),
+                            "type": "checkbox",
+                            "default": false
                         }
                     ]
                 },
@@ -226,6 +232,12 @@
                             "text": qsTranslate("GenerateSettingTranslate", "Video preview"),
                             "type": "checkbox",
                             "default": true
+                        },
+                        {
+                            "key": "audio_file_preview",
+                            "text": qsTranslate("GenerateSettingTranslate", "Music preview"),
+                            "type": "checkbox",
+                            "default": true
                         }
                     ]
                 },
