@@ -51,6 +51,7 @@
 #include "app/filesignalmanager.h"
 #include "dfmevent.h"
 #include "app/define.h"
+#include "drootfilemanager.h"
 
 #include "interfaces/dfmstandardpaths.h"
 #include "interfaces/defenderinterface.h"
@@ -60,6 +61,7 @@
 #include "views/dfilemanagerwindow.h"
 #include "views/dtagedit.h"
 #include "views/dfmopticalmediawidget.h"
+#include "views/dfmsidebar.h"
 
 #include "gvfs/networkmanager.h"
 #include "gvfs/gvfsmountmanager.h"
@@ -226,6 +228,30 @@ void AppController::actionOpenDisk(const QSharedPointer<DFMUrlBaseEvent> &event)
 
     if (fileUrl.path().contains("dfmroot:///sr") && blk->idUUID().isEmpty() && !drv->opticalBlank()) return; // 如果光驱的uuid为空（光盘未挂载）且不是空光盘的情况下
 
+    //判断url是否是形如：smb://host
+    if (FileUtils::isSmbHostOnly(fileUrl)) {
+        QString smbIp = event->url().host();
+        if (!smbIp.isEmpty()) {
+            QWidget *p = WindowManager::getWindowById(event->windowId());
+            if (p) {
+                DFMEventDispatcher::instance()->processEvent<DFMChangeCurrentUrlEvent>(this, fileUrl, p);
+                return;
+            }
+        }
+    }else{
+        QString ip;
+        if(FileUtils::isSmbRelatedUrl(fileUrl,ip)){
+            QWidget *p = WindowManager::getWindowById(event->windowId());
+            if (p) {
+                DUrl url;
+                url.setScheme(SMB_SCHEME);
+                url.setHost(ip);
+                DFMEventDispatcher::instance()->processEvent<DFMChangeCurrentUrlEvent>(this, url, p);
+                return;
+            }
+        }
+    }
+
     if (!mounted) {
         m_fmEvent = event;
         setEventKey(Open);
@@ -459,7 +485,10 @@ void AppController::actionCompleteDeletion(const QSharedPointer<DFMUrlListBaseEv
 
     bool slient { false };
     bool force { false };
-    DFMEventDispatcher::instance()->processEventAsync(dMakeEventPointer<DFMDeleteEvent>(sender, list, slient, force));
+    if (DThreadUtil::runInMainThread(dialogManager, &DialogManager::showDeleteFilesClearTrashDialog,
+                                     DFMUrlListBaseEvent(sender, list)) == DDialog::Accepted) {
+        DFMEventDispatcher::instance()->processEventAsync(dMakeEventPointer<DFMDeleteEvent>(sender, list, slient, force));
+    }
 }
 
 void AppController::actionCreateSymlink(const QSharedPointer<DFMUrlBaseEvent> &event)
@@ -525,6 +554,8 @@ void AppController::actionClearTrash(const QObject *sender)
 
     if (ret) {
         DDesktopServices::playSystemSoundEffect(DDesktopServices::SSE_EmptyTrash);
+    } else {
+        DFileService::instance()->setDoClearTrashState(false);
     }
 }
 
@@ -565,7 +596,6 @@ void AppController::actionNewText(const QSharedPointer<DFMUrlBaseEvent> &event)
 void AppController::actionMount(const QSharedPointer<DFMUrlBaseEvent> &event)
 {
     const DUrl &fileUrl = event->url();
-
     if (fileUrl.scheme() == DFMROOT_SCHEME) {
         auto path = fileUrl.path();
         // mount the stashed remote connections
@@ -606,6 +636,18 @@ void AppController::actionMount(const QSharedPointer<DFMUrlBaseEvent> &event)
         actionOpen(e);
         return;
     }
+    ///处理对smb设备根目录下共享文件夹的挂载操作 - start
+    else if (fileUrl.scheme() == SMB_SCHEME && FileUtils::isSmbShareFolder(fileUrl)) {
+        deviceListener->setBatchedRemovingSmbMount(false);
+        QString temUrl = fileUrl.toString();
+        if(!temUrl.endsWith(SUFFIX_STASHED_REMOTE))
+            temUrl.append('.').append(SUFFIX_STASHED_REMOTE);
+        QString path = RemoteMountsStashManager::normalizeConnUrl(temUrl);
+        auto e = dMakeEventPointer<DFMUrlBaseEvent>(event->sender(), path);
+        GvfsMountManager::instance()->mount_sync(*e);
+        return;
+    }
+    ///处理对smb设备根目录下共享文件夹的挂载操作 - end
 
     QStringList deviceNode = DDiskManager::resolveDeviceNode(fileUrl.query(), {});
     if(deviceNode.isEmpty()) {
@@ -737,7 +779,6 @@ void AppController::actionUnmount(const QSharedPointer<DFMUrlBaseEvent> &event)
 void AppController::doActionUnmount(const QSharedPointer<DFMUrlBaseEvent> &event)
 {
     const DUrl &fileUrl = event->url();
-
     if (fileUrl.scheme() == DFMROOT_SCHEME) {
         DAbstractFileInfoPointer fi = fileService->createFileInfo(event->sender(), fileUrl);
 
@@ -775,10 +816,22 @@ void AppController::doActionUnmount(const QSharedPointer<DFMUrlBaseEvent> &event
                 }
                 qInfo() << "umount path = " << path;
             }
-
             deviceListener->unmount(path);
         }
-    } else if (fileUrl.query().length()) {
+    }else if (fileUrl.scheme() == SMB_SCHEME && FileUtils::isSmbShareFolder(fileUrl)) {///处理对smb设备根目录下共享文件夹的卸载操作 - start
+        //todo(zhuangshu):对于相同的远端共享目录，采用不同的参数去挂载，会在/run/user/1000/gvfs/下面生成多个映射目录，
+        //而此处只能卸载其中的一个(除非用户选择卸载所有)，所以此处需要考虑把gvfs目录下面的所有远端共享目录都卸载，
+        //而且不能仅通过ip和username判断，因为用域名也可以挂载
+        QString path = fileUrl.path();
+        path = path.startsWith('/') ? path.mid(1) : path;
+        path = path.toLower();
+        QString tPath = fileUrl.scheme() + "://" + fileUrl.host() + "/" +path;
+        path = fileUrl.scheme() + "://" + fileUrl.host() + "/" + QUrl::toPercentEncoding(path,"{$}") + "/";
+        deviceListener->unmount(path);
+        doRemoveStashedMount(tPath);//这里需要移除缓存
+        return;
+        ///处理对smb设备根目录下共享文件夹的卸载操作 - end
+    }else if (fileUrl.query().length()) {
         QString dev = fileUrl.query(DUrl::FullyEncoded);
         deviceListener->unmount(dev);
     }
@@ -966,7 +1019,31 @@ void AppController::actionProperty(const QSharedPointer<DFMUrlListBaseEvent> &ev
 
         DUrl gvfsmpurl;
         gvfsmpurl.setScheme(DFMROOT_SCHEME);
-        gvfsmpurl.setPath("/" + QUrl::toPercentEncoding(url.path()) + "." SUFFIX_GVFSMP);
+        if(FileUtils::isSmbShareFolder(url)){//url like: smb://host/share_fodler
+            QString formatPath("/run/user/%1/gvfs/smb-share:server=%2,share=%3");
+            QString scheme = url.scheme();
+            QUrl tem = QUrl::fromPercentEncoding(url.toString().toLocal8Bit());
+            QString path = tem.path();
+            if(!path.isEmpty()){
+                QString ip = tem.host();
+                QString dirName = path.split("/").last();
+                formatPath = formatPath.arg(getuid()).arg(ip).arg(dirName.toLower());
+                DUrl mountUrl;
+                mountUrl.setScheme(DFMROOT_SCHEME);
+                mountUrl.setPath("/" + QUrl::toPercentEncoding(formatPath + "." SUFFIX_GVFSMP));
+                bool isMounted = FileUtils::isNetworkUrlMounted(mountUrl);
+                if(isMounted){
+                    gvfsmpurl.setPath("/" + QUrl::toPercentEncoding(formatPath + "." SUFFIX_GVFSMP));
+                }else{
+                    QString path = tem.toString().prepend("/").append("." SUFFIX_STASHED_REMOTE);
+                    gvfsmpurl.setPath("/" + QUrl::toPercentEncoding(path) + "." SUFFIX_GVFSMP);
+                    urlList.clear();
+                    urlList.append(DUrl(path.prepend(DFMROOT_ROOT)));
+                }
+            }
+        }else
+            gvfsmpurl.setPath("/" + QUrl::toPercentEncoding(url.path()) + "." SUFFIX_GVFSMP);
+
         DAbstractFileInfoPointer fp(new DFMRootFileInfo(gvfsmpurl));
         if (fp->exists()) {
             url = gvfsmpurl;
@@ -1117,14 +1194,20 @@ void AppController::actionOpticalBlank(const QSharedPointer<DFMUrlBaseEvent> &ev
 
 void AppController::actionRemoveStashedMount(const QSharedPointer<DFMUrlBaseEvent> &event)
 {
-    auto path = event->url().path(); // something like "/smb://1.2.3.4/shared-folder.remote"
-    path = RemoteMountsStashManager::normalizeConnUrl(path);
+    auto path = event->url().path(); // something like "/smb://host/shared-folder.remote"
+    doRemoveStashedMount(path);
+}
+
+void AppController::doRemoveStashedMount(const QString &path)
+{
     // then find the stashed key of it.
     const auto &&stashedRemoteMounts = RemoteMountsStashManager::remoteMounts();
     QString key;
+    QString smbHost;
     for (const auto &mount: stashedRemoteMounts) {
         auto protocol = mount.value(REMOTE_PROTOCOL).toString();
         auto host = mount.value(REMOTE_HOST).toString();
+        smbHost = host;
         auto share = mount.value(REMOTE_SHARE).toString();
         if (protocol.isEmpty() || host.isEmpty()) {
             qWarning() << "protocol or host is empty: " << mount;
@@ -1142,6 +1225,99 @@ void AppController::actionRemoveStashedMount(const QSharedPointer<DFMUrlBaseEven
     }
 }
 
+/**
+ * @brief AppController::actionUnmountAllSmbMount 通过侧边栏SMB子项的右键菜单“卸载”项，卸载所有已挂载的SMB目录
+ * @param event event->urlList为需要卸载的SMB地址列表
+ */
+void AppController::actionUnmountAllSmbMount(const QSharedPointer<DFMUrlListBaseEvent> &event)
+{
+    DUrlList urlList = event->urlList();
+    DUrlList list;//保存需要卸载的smb挂载url
+    if(urlList.count() <= 0){
+        qInfo()<<"When unmount all, the urlList is empty.";
+        return;
+    }
+    DUrl eventUrl = urlList.first();
+    qInfo()<<eventUrl;
+    if (!FileUtils::isSmbHostOnly(eventUrl)){//确保eventUrl为smb://host格式
+        qInfo()<<"When unmount all, the eventUrl is not a smb device.";
+        return;
+    }
+    QString host = eventUrl.host();
+    //从侧边栏和计算机界面通过右键菜单批量卸载smb挂载，都会执行下面代码收集当前设备的挂载项（修复：不能从计算机界面批量卸载的问题）
+    QList<DAbstractFileInfoPointer> filist  = rootFileManager->getRootFile();
+    foreach (DAbstractFileInfoPointer r, filist) {
+        QString temIp;
+        bool isSmbRelated = FileUtils::isSmbRelatedUrl(r->fileUrl(),temIp);
+        if ( (!isSmbRelated) || (!r->fileUrl().toString().contains(host)))//!isSmbRelated:排除ftp挂载
+            continue;
+
+        if (r->fileUrl().toString().endsWith(QString(".%1").arg(SUFFIX_GVFSMP)) && FileUtils::isNetworkUrlMounted(r->fileUrl())){
+            list << r->fileUrl();
+        }
+    }
+    //设置批量移除smb挂载标志，用途：最后一个卸载后才刷新、跳转到计算机界面
+    deviceListener->setBatchedRemovingSmbMount(true);
+    //若侧边栏有SMB挂载子项，但并没有已挂载的SMB文件夹
+    foreach (DUrl url, list) {
+        QString smbLocalPath = QString("/run/user/%1/gvfs").arg(getuid())+QUrl::fromPercentEncoding(url.path().mid(1).chopped(QString("." SUFFIX_GVFSMP).length()).toUtf8());
+        QString smbUser = FileUtils::smbAttribute(smbLocalPath,FileUtils::SmbAttribute::kUser);
+        QString smbDomain = FileUtils::smbAttribute(smbLocalPath,FileUtils::SmbAttribute::kDomain);
+        QString smbServer = FileUtils::smbAttribute(smbLocalPath,FileUtils::SmbAttribute::kServer);
+        QString smbShareName = FileUtils::smbAttribute(smbLocalPath,FileUtils::SmbAttribute::kShareName);
+        if (smbShareName.isEmpty())
+            continue;
+        QString unmountPath;
+        // A fully smbLocalPath like : smb-share:domain=WORKGROUP,server=x.x.x.x,share=share_folder,user=username
+        if (!smbDomain.isEmpty() && !smbUser.isEmpty()) {
+            unmountPath = QString("%1://%2;%3@%4/%5/").arg(SMB_SCHEME).arg(smbDomain).arg(smbUser).arg(smbServer).arg(smbShareName);
+        }else if (smbDomain.isEmpty() && !smbUser.isEmpty()) {
+            unmountPath = QString("%1://%2@%3/%4/").arg(SMB_SCHEME).arg(smbUser).arg(smbServer).arg(smbShareName);
+        }else {
+            unmountPath = QString("%1://%2/%3/").arg(SMB_SCHEME).arg(smbServer).arg(smbShareName);
+        }
+        QUrl temUrl(unmountPath);
+        unmountPath = temUrl.toEncoded(QUrl::PrettyDecoded);//这种编码方式会保留$、把空格编码为%20、把中文也编码（而toPercentEncoding会把$也编码，导致卸载问题）
+        deviceListener->unmount(unmountPath);
+        unmountPath.chop(1);
+        doRemoveStashedMount(unmountPath);//这里需要移除缓存
+    }
+    //如果list.isEmpty()，则下面需主动从侧边栏移除SMB挂载子项
+    DFileManagerWindow* managerWindow = qobject_cast<DFileManagerWindow *>(WindowManager::getWindowById(event->windowId()));
+    if (managerWindow && list.isEmpty()) {
+        QTimer::singleShot(125, [=]() {
+        //如果前面没有smb目录卸载操作，在这里主动跳转到计算机页面;（场景：用户只是在地址栏输入了smb host，但是没有做目录挂载操作）
+        //反之则在侧边栏的fileDeleted中槽函数中触发界面跳转
+        //如果上述没有发生挂载目录的卸载操作，则不会触发卸载通知，因此在这里主动移除smb挂载聚合项
+            RemoteMountsStashManager::removeStashedSmbDevice(eventUrl.toString());
+            emit rootFileManager->rootFileWather()->fileDeleted(eventUrl);//多个打开的窗口同步移除smb挂载聚合项
+            managerWindow->getLeftSideBar()->jumpToItem(DUrl(COMPUTER_ROOT));
+            emit DFMApplication::instance()->reloadComputerModel();//刷新计算机界面上的smb聚合设备
+        });
+    }
+}
+
+/**
+ * @brief AppController::actionForgetAllSmbPassword 用户手动从侧边栏对smb挂载子项点击右键菜单中的“取消记住密码并移除”
+ * @param event
+ */
+void AppController::actionForgetAllSmbPassword(const QSharedPointer<DFMUrlListBaseEvent> &event)
+{
+    DUrlList urlList = event->urlList();
+    QString smbIp;
+    //1、取消记住密码
+    foreach (DUrl url, urlList) {
+        if(FileUtils::isSmbRelatedUrl(url,smbIp)){
+//            DUrl temUrl(QString("%1://%2").arg(SMB_SCHEME).arg(smbIp));
+            secretManager->clearPassworkBySmbHost(url);
+            break;
+        }
+    }
+    deviceListener->clearLoginData();//清除登录数据，以便下次重新弹出鉴权对话框
+    //2、卸载smbIp下的所有smb挂载目录
+    actionUnmountAllSmbMount(event);
+}
+
 void AppController::actionctrlL(quint64 winId)
 {
     emit fileSignalManager->requestSearchCtrlL(winId);
@@ -1186,15 +1362,30 @@ void AppController::actionForward(quint64 winId)
 
 void AppController::actionForgetPassword(const QSharedPointer<DFMUrlBaseEvent> &event)
 {
-    QString path;
     DAbstractFileInfoPointer fi = fileService->createFileInfo(event->sender(), event->url());
-    if (fi && fi->suffix() == SUFFIX_GVFSMP) {
+    if(fi == nullptr)
+        return;
+    QString path = fi->fileUrl().toString();
+    if (fi->suffix() == SUFFIX_GVFSMP) {
         path = QUrl(fi->extraProperties()["rooturi"].toString()).toString();
+    }else if(FileUtils::isSmbPath(path)){
+        if(!path.endsWith("/"))
+            path.append("/");
     }
+    doForgetPassword(path);
+    actionUnmount(event);
+    auto stashKey = fi->extraProperties()["backer_url"].toString();
+    if(stashKey.isEmpty())
+        stashKey = QString("/run/user/%1/gvfs/smb-share:server=%2,share=%3")
+                .arg(getuid()).arg(event->url().host()).arg(event->url().path().mid(1));
+
+    RemoteMountsStashManager::removeRemoteMountItem(stashKey);
+}
+
+void AppController::doForgetPassword(const QString &path)
+{
     QJsonObject smbObj = secretManager->getLoginData(path);
-
     qDebug() << path << smbObj;
-
     if (!smbObj.empty()) {
         QStringList ids = path.split("/");
         QString domain;
@@ -1225,10 +1416,6 @@ void AppController::actionForgetPassword(const QSharedPointer<DFMUrlBaseEvent> &
         obj.insert("key", smbObj.value("key").toString());
         secretManager->clearPasswordByLoginObj(obj);
     }
-    actionUnmount(event);
-
-    auto stashKey = fi->extraProperties()["backer_url"].toString();
-    RemoteMountsStashManager::removeRemoteMountItem(stashKey);
 }
 
 void AppController::actionOpenFileByApp()
