@@ -34,6 +34,8 @@
 #include "dfmapplication.h"
 #include "dfmsettings.h"
 #include "utils.h"
+#include "utils/grouppolicy.h"
+#include "app/define.h"
 
 #include <dgiofile.h>
 #include <dgiofileinfo.h>
@@ -206,6 +208,15 @@ const QList<DAbstractFileInfoPointer> DFMRootController::getChildren(const QShar
         }
     }
 
+    bool hasSetDiskPolicy;
+    QStringList diskPolicyList;
+    QStringList hintSystemDisks;
+    if (DTK_POLICY_SUPPORT) {
+        hasSetDiskPolicy = GroupPolicy::instance()->containKey(DISK_HIDDEN);
+        if (hasSetDiskPolicy)
+            diskPolicyList = GroupPolicy::instance()->getValue(DISK_HIDDEN).toStringList();
+    }
+
     QStringList blkds = DDiskManager::blockDevices({});
     for (auto blks : blkds) {
         QSharedPointer<DBlockDevice> blk(DDiskManager::createBlockDevice(blks));
@@ -216,10 +227,22 @@ const QList<DAbstractFileInfoPointer> DFMRootController::getChildren(const QShar
 
         reloadBlkName(blks, blk);
 
-        using namespace DFM_NAMESPACE;
-        if (DFMApplication::genericAttribute(DFMApplication::GA_HiddenSystemPartition).toBool() && blk->hintSystem()) {
-            qDebug()  << "block device is ignored by hintSystem&HiddenSystemPartition:"  << blks;
-            continue;
+        if (DTK_POLICY_SUPPORT) {
+            if (hasSetDiskPolicy && blk->hintSystem() && diskPolicyList.contains(blk->idUUID()))
+                continue;
+
+            if (blk->hintSystem())
+                hintSystemDisks << blk->idUUID();
+
+            if (!hasSetDiskPolicy && DFMApplication::genericAttribute(DFMApplication::GA_HiddenSystemPartition).toBool() && blk->hintSystem()) {
+                qDebug()  << "block device is ignored by hintSystem&HiddenSystemPartition:"  << blks;
+                continue;
+            }
+        } else {
+            if (DFMApplication::genericAttribute(DFMApplication::GA_HiddenSystemPartition).toBool() && blk->hintSystem()) {
+                qDebug()  << "block device is ignored by hintSystem&HiddenSystemPartition:"  << blks;
+                continue;
+            }
         }
 
         DAbstractFileInfoPointer fp(new DFMRootFileInfo(DUrl(DFMROOT_ROOT + QString(blk->device()).mid(QString("/dev/").length()) + "." SUFFIX_UDISKS)));
@@ -303,7 +326,12 @@ const QList<DAbstractFileInfoPointer> DFMRootController::getChildren(const QShar
                 qWarning() << "protocol or host is empty: " << mount;
                 continue;
             }
-
+            //考虑到用户升级到有smb挂载项聚合功能的版本后的兼容性，把配置中缓存的.remote挂载信息移到StashedSmbDevices字段中
+            //以smb://x.x.x.x格式保存
+            if(protocol == SMB_SCHEME){
+                RemoteMountsStashManager::insertStashedSmbDevice(QString("%1://%2").arg(protocol).arg(host));
+            }
+            /*smb挂载项聚合功能中，这里不再对缓存的挂载目录创建DFMRootFileInfo对象（请保留此部分注释）
             QString path = QString("%1://%2/%3").arg(protocol).arg(host).arg(share);
             path.append(QString(".%1").arg(SUFFIX_STASHED_REMOTE));
             path.prepend(DFMROOT_ROOT);
@@ -312,14 +340,39 @@ const QList<DAbstractFileInfoPointer> DFMRootController::getChildren(const QShar
             auto stashedMountInfo = new DFMRootFileInfo(DUrl::fromPercentEncoding(path.toUtf8()));
             DAbstractFileInfoPointer fp(stashedMountInfo);
             ret.push_back(fp);
+            */
         }
     }
 
+
+
     qInfo() << "get rootfileinfo over !" << ret;
     for(auto item: ret) {
         qInfo() << item->fileUrl();
     }
 
+    if (DTK_POLICY_SUPPORT && hasSetDiskPolicy) {
+        if (diskPolicyList.isEmpty()) {
+            // 同步组策略到老配置(不选中隐藏)
+            DFMApplication::instance()->setGenericAttribute(DFMApplication::GA_HiddenSystemPartition, false);
+            return ret;
+        }
+
+        bool allSet = true;
+        for (auto blk : hintSystemDisks) {
+            if (!diskPolicyList.contains(blk))
+                allSet = false;
+        }
+
+        // 同步组策略到老配置(选中隐藏)
+
+        if (allSet) {
+            DFMApplication::instance()->setGenericAttribute(DFMApplication::GA_HiddenSystemPartition, true);
+        } else {
+            DFMApplication::instance()->setGenericAttribute(DFMApplication::GA_HiddenSystemPartition, false);
+        }
+    }
+
     return ret;
 }
 
@@ -333,6 +386,23 @@ DAbstractFileWatcher *DFMRootController::createFileWatcher(const QSharedPointer<
     return new DFMRootFileWatcher(event->url());
 }
 
+QStringList DFMRootController::systemDiskList()
+{
+    QStringList tempList;
+    QStringList blkds = DDiskManager::blockDevices({});
+
+    for (auto blks : blkds) {
+        QSharedPointer<DBlockDevice> blk(DDiskManager::createBlockDevice(blks));
+        QSharedPointer<DDiskDevice> drv(DDiskManager::createDiskDevice(blk->drive()));
+        if(ignoreBlkDevice(blks, blk, drv))
+            continue;
+
+        if (blk->hintSystem())
+            tempList << blk->idUUID();
+    }
+    return tempList;
+}
+
 void DFMRootController::loadDiskInfo(const QString &jsonPath) const
 {
     //不存在该目录
@@ -545,7 +615,6 @@ bool DFMRootFileWatcherPrivate::start()
         if (mnt->getVolume() && mnt->getVolume()->volumeMonitorName().endsWith("UDisks2")) {
             return;
         }
-
         DUrl url;
         url.setScheme(DFMROOT_SCHEME);
         QString path = mnt->getRootFile()->path();
@@ -571,13 +640,20 @@ bool DFMRootFileWatcherPrivate::start()
         }
         qDebug() << path;
         url.setPath("/" + QUrl::toPercentEncoding(path) + "." SUFFIX_GVFSMP);
-        Q_EMIT wpar->fileDeleted(url);
         QString uri = mnt->getRootFile()->uri();
-        fileSignalManager->requestRemoveRecentFile(path);
+        wpar->setProperty("isBathUnmuntSmb",deviceListener->isBatchedRemovingSmbMount());
+        wpar->setProperty("remainUnmuntSmb",deviceListener->getCountOfMountedSmb(DUrl(uri).host()));
+        Q_EMIT wpar->fileDeleted(url);
+        emit fileSignalManager->requestRemoveRecentFile(path);
         qDebug() << uri << "mount removed";
         if (FileUtils::isSmbPath(path)) {
-            emit fileSignalManager->requestFreshAllFileView();
-            emit fileSignalManager->requestFreshAllDesktop();
+          int remainCountOfSmbMount = deviceListener->getCountOfMountedSmb(DUrl(uri).host());
+          if(!(deviceListener->isBatchedRemovingSmbMount() && remainCountOfSmbMount >0)){//批量卸载SMB时，需卸载完毕再刷新界面以避免卡顿
+              deviceListener->setBatchedRemovingSmbMount(false);
+              emit fileSignalManager->requestFreshAllFileView();
+              emit fileSignalManager->requestFreshAllDesktop();
+           }
+
         }
         if (uri.contains("smb-share://") || uri.contains("smb://") || uri.contains("ftp://") || uri.contains("sftp://")) {
             // remove NetworkNodes cache, so next time cd uri will fetchNetworks
@@ -596,7 +672,6 @@ bool DFMRootFileWatcherPrivate::start()
             NetworkManager::NetworkNodes.remove(smbUrl);
             smbUrl.setPath("");
             NetworkManager::NetworkNodes.remove(smbUrl);
-
             mnt->unmount(); // yes, we need do it again...otherwise we will goto an removed path like /run/user/1000/gvfs/smb-sharexxxx
         }
     }));
