@@ -46,7 +46,7 @@ DFMSideBarItem *DFMSideBarBookmarkItemHandler::createItem(const DUrl &url)
     QString displayName = url.bookmarkName();
 
     QIcon icon = QIcon::fromTheme("folder-bookmark-symbolic");
-    DFMSideBarItem * item = new DFMSideBarItem(icon, displayName, url);
+    DFMSideBarItem * item = new DFMSideBarItem(icon, displayName, url, "bookmark");
 
     item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsDragEnabled | Qt::ItemIsEditable | Qt::ItemNeverHasChildren);
     item->setRegisteredHandler(SIDEBAR_ID_BOOKMARK);
