@@ -67,6 +67,7 @@
 #include "deviceinfo/udisklistener.h"
 #include "deviceinfo/udiskdeviceinfo.h"
 #include "controllers/vaultcontroller.h"
+#include "controllers/masteredmediacontroller.h"
 
 #include <QDesktopServices>
 #include <QDirIterator>
@@ -86,13 +87,6 @@
 
 #include "dfmsettings.h"
 #include "dfmapplication.h"
-#ifndef DISABLE_QUICK_SEARCH
-#include "anything_interface.h"
-#endif
-#ifdef DISABLE_QUICK_SEARCH
-#include "./search/dfsearch.h"
-#include "vaultcontroller.h"
-#endif
 
 class DFMQDirIterator : public DDirIterator
 {
@@ -233,305 +227,6 @@ private:
     QFileInfo currentFileInfo;
 };
 
-#ifndef DISABLE_QUICK_SEARCH
-class DFMAnythingDirIterator : public DDirIterator
-{
-public:
-    DFMAnythingDirIterator(ComDeepinAnythingInterface *u,
-                           const QString &path, const QString &k)
-        : interface(u)
-            , keyword(k)
-            , dir(path)
-    {
-        keyword = DFMRegularExpression::checkWildcardAndToRegularExpression(keyword);
-    }
-
-    ~DFMAnythingDirIterator() override
-    {
-
-    }
-
-    DUrl next() override
-    {
-        currentFileInfo.setFile(searchResults.takeFirst());
-
-        return fileUrl();
-    }
-
-    bool hasNext() const override
-    {
-        if (!initialized) {
-            const QString &dir_path = dir.absolutePath();
-            // 如果挂载在此路径下的其它目录也支持索引数据, 则一并搜索
-            searchDirList << interface->hasLFTSubdirectories(dir_path);
-
-            if (searchDirList.isEmpty() || searchDirList.first() != dir_path) {
-                searchDirList.prepend(dir_path);
-            }
-
-            initialized = true;
-        }
-
-        while (searchResults.isEmpty() && !searchDirList.isEmpty()) {
-            const auto result = interface->search(100, 500, searchStartOffset, searchEndOffset, searchDirList.first(), keyword, true);
-
-            searchResults = result.argumentAt<0>();
-            searchStartOffset = result.argumentAt<1>();
-            searchEndOffset = result.argumentAt<2>();
-
-            // 当前目录已经搜索到了结尾
-            if (searchStartOffset >= searchEndOffset) {
-                searchStartOffset = searchEndOffset = 0;
-                searchDirList.removeAt(0);
-            }
-
-            // 如果路径中存在链接，需要将其还原，用于展示
-            if (m_hasSymLink) {
-                for (auto &path : searchResults) {
-                    path.replace(m_newPrefix, m_oldPrefix);
-                    if (m_isAddDataPrefix && path.startsWith("/data"))
-                        path.remove(0, 5);
-                }
-            } else if (m_isAddDataPrefix) {
-                for (auto &path : searchResults) {
-                    if (path.startsWith("/data"))
-                        path.remove(0, 5);
-                }
-            }
-        }
-
-        return !searchResults.isEmpty();
-    }
-
-    QString fileName() const override
-    {
-        return currentFileInfo.fileName();
-    }
-
-    DUrl fileUrl() const override
-    {
-        return DUrl::fromLocalFile(currentFileInfo.filePath());
-    }
-
-    const DAbstractFileInfoPointer fileInfo() const override
-    {
-        bool currentisgvfs = FileUtils::isGvfsMountFile(currentFileInfo.path(), true);
-        if (currentisgvfs) {
-            return DAbstractFileInfoPointer(new DGvfsFileInfo(currentFileInfo, false));
-        }
-        return DAbstractFileInfoPointer(new DFileInfo(currentFileInfo));
-    }
-
-    DUrl url() const override
-    {
-        return DUrl::fromLocalFile(dir.absolutePath());
-    }
-
-    ///
-    /// \brief setPathPropertity 设置路径属性
-    /// \param hasSymLink 是否存在链接目录
-    /// \param oldPrefix 原始前缀
-    /// \param newPrefix 修改后的前缀
-    /// \param isAddDataPrefix 是否添加了data目录前缀
-    ///
-    void setPathPropertity(bool hasSymLink, const QString &oldPrefix, const QString &newPrefix, const bool isAddDataPrefix)
-    {
-        m_hasSymLink = hasSymLink;
-        m_oldPrefix = oldPrefix;
-        m_newPrefix = newPrefix;
-        m_isAddDataPrefix = isAddDataPrefix;
-    }
-
-private:
-    ComDeepinAnythingInterface *interface;
-    QString keyword;
-
-    mutable bool initialized = false;
-    mutable QStringList searchDirList;
-    mutable quint32 searchStartOffset = 0, searchEndOffset = 0;
-    mutable QStringList searchResults;
-
-    bool m_hasSymLink = false;
-    bool m_isAddDataPrefix = false;
-    QString m_oldPrefix;
-    QString m_newPrefix;
-
-    QDir dir;
-    QFileInfo currentFileInfo;
-};
-#endif // DISABLE_QUICK_SEARCH
-
-#ifdef DISABLE_QUICK_SEARCH
-//#if 0
-void Delay_MSec(unsigned int msec)
-{
-    QTime dieTime = QTime::currentTime().addMSecs(msec);
-
-    while (QTime::currentTime() < dieTime)
-
-        QCoreApplication::processEvents(QEventLoop::AllEvents, 100);
-
-}
-QString printList(BTreeNode *pNode)
-{
-
-    QString fullPath("");
-    if (pNode == nullptr) {
-        return "";
-    } else {
-        int i = 0;
-        while (pNode != nullptr) {
-            if (pNode->name != nullptr) {
-                fullPath.insert(0, pNode->name);
-                if (strcmp(pNode->name, "") != 0) {
-                    fullPath.insert(0, "/");
-                }
-            }
-            pNode = pNode->parent;
-            i++;
-        }
-    }
-
-    return fullPath;
-}
-
-class DFMFSearchDirIterator : public DDirIterator
-{
-public:
-    DFMFSearchDirIterator(const QString &path, const QString &k)
-        : keyword(k)
-        , dir(path)
-    {
-        dfsearch = new DFSearch(path, this);
-    }
-
-    ~DFMFSearchDirIterator() override
-    {
-        if (dfsearch) {
-            delete dfsearch;
-            dfsearch = nullptr;
-        }
-    }
-
-    static void callbackFunc(void *back, void *self)
-    {
-        if (!self || !back) {
-            return;
-        }
-        DFMFSearchDirIterator *it = static_cast<DFMFSearchDirIterator *>(self);
-        DatabaseSearch *result = static_cast<DatabaseSearch *>(back);
-        if (!result)
-            return;
-        GPtrArray *results = result->results;
-        if (results && results->len > 0) {
-            uint32_t num_results = results->len;
-            for (uint32_t j = 0; j < num_results; j++) {
-                if (results->len > 0 && results->pdata) {
-                    DatabaseSearchEntry *entry = static_cast<DatabaseSearchEntry *>(g_ptr_array_index(results, j));
-                    QString strResult = "";
-                    if (entry && entry->node) {
-                        strResult = printList(entry->node);
-                    }
-
-                    if (!strResult.isEmpty()) {
-                        /*fix task 30348 针对搜索不能搜索部分目录，可以将根目录加入索引库，搜索结果出来以后进行当前目录过滤就可以*/
-                        QFileInfo info(strResult);
-                        QString fullPath = info.absoluteFilePath();
-                        QString filePath = info.absolutePath();
-                        if (filePath.startsWith(it->dir.absolutePath()) && !it->searchResults.contains(fullPath)) {
-                            // 修复wayland-bug-51754
-                            // 刷选出保险箱内的文件,使其不被检索出来
-                            if (!VaultController::isVaultFile(it->dir.absolutePath()) && VaultController::isVaultFile(fullPath))
-                                continue;
-                            it->searchResults.append(strResult);
-                        }
-                    }
-                }
-            }
-            qDebug() << "-------callback:" << num_results;
-        }
-        it->mDone = true;
-    }
-
-    DUrl next() override
-    {
-        currentFileInfo.setFile(searchResults.takeFirst());
-
-        return fileUrl();
-    }
-
-    bool hasNext() const override
-    {
-        if (!initialized) {
-            const QString &dir_path = dir.absolutePath();
-            //fix bug62654,搜索过程中有的时候无法搜索到东西，需要先清理搜索结果，再进行搜索
-            searchResults.clear();
-            if (searchDirList.isEmpty() || searchDirList.first() != dir_path) {
-                searchDirList.prepend(dir_path);
-                dfsearch->searchByKeyWord(keyword, callbackFunc);
-                qDebug() << "*******************************find";
-                mDone = false;
-            }
-
-            initialized = true;
-        }
-        if (!resultinit) {
-            int i = 0;
-            while (!closed) {
-                std::this_thread::sleep_for(std::chrono::seconds(1));
-                if (mDone || i++ > 10) {
-                    break;
-                }
-            }
-        }
-
-        resultinit = true;
-        searchDirList.removeAt(0);
-        return !searchResults.isEmpty();
-    }
-
-    QString fileName() const override
-    {
-        return currentFileInfo.fileName();
-    }
-
-    DUrl fileUrl() const override
-    {
-        return DUrl::fromLocalFile(currentFileInfo.filePath());
-    }
-
-    const DAbstractFileInfoPointer fileInfo() const override
-    {
-        return DAbstractFileInfoPointer(new DFileInfo(currentFileInfo));
-    }
-
-    DUrl url() const override
-    {
-        return DUrl::fromLocalFile(dir.absolutePath());
-    }
-
-    void close() override
-    {
-        closed = true;
-        if (dfsearch)
-            dfsearch->stop();
-    }
-private:
-    QString keyword;
-    mutable bool resultinit = false;
-    mutable bool initialized = false;
-    mutable QStringList searchDirList;
-    mutable quint32 searchStartOffset = 0, searchEndOffset = 0;
-    mutable QStringList searchResults;
-
-    mutable bool mDone = false;
-    bool closed = false;
-    DFSearch *dfsearch = nullptr;
-    QDir dir;
-    QFileInfo currentFileInfo;
-};
-#endif // DISABLE_FSEARCH
-
 class FileDirIterator : public DDirIterator
 {
 public:
@@ -550,20 +245,8 @@ public:
     const DAbstractFileInfoPointer fileInfo() const override;
     DUrl url() const override;
     void close() override;
-
     bool enableIteratorByKeyword(const QString &keyword) override;
 
-    ///
-    /// \brief hasSymLinkDir 用于判断当前路径中是否存在快捷方式
-    /// \param path 需要判断的路径
-    /// \return
-    ///
-    bool hasSymLinkDir(const QString &path);
-
-    QString realSearchPath; // 真实的搜索路径
-    QString oldPrefix;      // 记录链接路径
-    QString newPrefix;      // 记录链接指向的路径
-
     DFMFileListFile *hiddenFiles = nullptr;
 
 private:
@@ -1294,6 +977,10 @@ DUrlList FileController::pasteFilesV2(const QSharedPointer<DFMPasteEvent> &event
         if(!targetUrlList.isEmpty() && targetUrlList.at(0).toLocalFile().contains(VaultController::makeVaultLocalPath())) {
             emit VaultController::ins()->sigFinishedCopyFile();
         }
+        // 光盘缓存文件映射
+        if (!targetUrlList.isEmpty() && targetUrlList.at(0).burnIsOnLocalStaging()) {
+            MasteredMediaController::mapStagingFilesPath(thisJob->sourceUrlList(), targetUrlList);
+        }
     });
 
     return job->targetUrlList();
@@ -1973,78 +1660,7 @@ void FileDirIterator::close()
 
 bool FileDirIterator::enableIteratorByKeyword(const QString &keyword)
 {
-#ifdef DISABLE_QUICK_SEARCH
-    Q_UNUSED(keyword);
-//    return false;
-#else // !DISABLE_QUICK_SEARCH
-    QString pathForSearching = iterator->url().toLocalFile();
+    Q_UNUSED(keyword)
 
-    static ComDeepinAnythingInterface anything("com.deepin.anything", "/com/deepin/anything",
-                                               QDBusConnection::systemBus());
-
-    bool isAddDataPrefix = false;
-    if (!anything.hasLFT(pathForSearching)) {
-        if (pathForSearching.startsWith("/home") && QDir("/data/home").exists()) {
-            pathForSearching.prepend("/data");
-            if (!anything.hasLFT(pathForSearching))
-                return false;
-            isAddDataPrefix = true;
-        } else {
-            return false;
-        }
-    } else {
-        qDebug() << "support quick search for: " << pathForSearching;
-    }
-
-    // fix bug#48091 当文件路径中存在快捷方式时，将其转换为真实地址
-    bool hasLink = false;
-    if (hasSymLinkDir(pathForSearching)) {
-        hasLink = true;
-        pathForSearching = realSearchPath;
-    }
-
-    if (iterator)
-        delete iterator;
-
-    iterator = new DFMAnythingDirIterator(&anything, pathForSearching, keyword);
-    static_cast<DFMAnythingDirIterator *>(iterator)->setPathPropertity(hasLink, oldPrefix, newPrefix, isAddDataPrefix);
-
-    return true;
-#endif // DISABLE_QUICK_SEARCH
-
-#ifdef DISABLE_QUICK_SEARCH
-    const QString pathForSearching = iterator->url().toLocalFile();
-    if (!DFSearch::isSupportFSearch(pathForSearching))
-        return false;
-
-    if (iterator)
-        delete iterator;
-
-    iterator = new DFMFSearchDirIterator(pathForSearching, keyword);
-
-    return true;
-#endif
-}
-
-bool FileDirIterator::hasSymLinkDir(const QString &path)
-{
-    QFileInfo info(path);
-    if (info.isSymLink()) {
-        oldPrefix = path;
-        newPrefix = info.symLinkTarget();
-        realSearchPath.prepend(newPrefix);
-        if (oldPrefix.startsWith("/data") && newPrefix.startsWith("/home")) {
-            realSearchPath.prepend("/data");
-            newPrefix.prepend("/data");
-        }
-        return true;
-    } else {
-        int last_dir_split_pos = path.lastIndexOf('/');
-        if (last_dir_split_pos <= 0)
-            return false;
-
-        realSearchPath.prepend(path.mid(last_dir_split_pos));
-        QString tmp = path.left(last_dir_split_pos);
-        return hasSymLinkDir(tmp);
-    }
+    return false;
 }
