@@ -23,9 +23,6 @@
 
 #include "jobcontroller.h"
 #include "dfileservices.h"
-#ifdef  FULLTEXTSEARCH_ENABLE
-#include "fulltextsearch.h"
-#endif
 
 #include <QtConcurrent/QtConcurrent>
 
@@ -241,8 +238,5 @@ void JobController::setState(JobController::State state)
         return;
 
     m_state = state;
-#ifdef  FULLTEXTSEARCH_ENABLE
-    DFMFullTextSearchManager::getInstance()->setSearchState(state);
-#endif
     emit stateChanged(state);
 }
