@@ -35,6 +35,8 @@
 #include "dialogs/dialogmanager.h"
 #include "dialogs/burnoptdialog.h"
 #include "interfaces/dfileproxywatcher.h"
+#include "interfaces/dfmapplication.h"
+#include "interfaces/dfmsettings.h"
 #include "private/dabstractfilewatcher_p.h"
 #include "disomaster.h"
 #include "shutil/fileutils.h"
@@ -330,7 +332,7 @@ DUrlList MasteredMediaController::moveToTrash(const QSharedPointer<DFMMoveToTras
             retlst.push_back(i);
         }
     }
-    fileService->deleteFiles(event->sender(), lst, false);
+    fileService->deleteFiles(event->sender(), lst, true);
 
     return retlst;
 }
@@ -510,17 +512,20 @@ DAbstractFileWatcher *MasteredMediaController::createFileWatcher(const QSharedPo
 DUrl MasteredMediaController::getStagingFile(DUrl dst)
 {
     Q_ASSERT(dst.burnDestDevice().length() > 0);
+    QString device = dst.burnDestDevice().replace("/", "_");
+    QString burnFile = dst.burnFilePath();
     return DUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation)
                                + "/" + qApp->organizationName() + "/" DISCBURN_STAGING "/"
-                               + dst.burnDestDevice().replace('/', '_')
-                               + dst.burnFilePath());
+                               + device
+                               + burnFile);
 }
 
 DUrl MasteredMediaController::getStagingFile(QString dev)
 {
+    QString temDev = dev.replace('/','_');
     return DUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation)   // ~/.cache
                   + "/" + qApp->organizationName() + "/" DISCBURN_STAGING "/"                           // ~/.cache/deepin/discburn/
-                  + dev.replace('/','_'));                                                              // ~/.cache/deepin/discburn/_dev_srN
+                  + temDev);                                                              // ~/.cache/deepin/discburn/_dev_srN
 }
 
 QFileDevice::Permissions MasteredMediaController::getPermissionsCopyToLocal()
@@ -531,3 +536,31 @@ QFileDevice::Permissions MasteredMediaController::getPermissionsCopyToLocal()
                                                                 | QFileDevice::ReadOther);
     return permissionsToLocal;
 }
+
+void MasteredMediaController::mapStagingFilesPath(const DUrlList &srcList, const DUrlList &targetList)
+{
+    if (srcList.size() != targetList.size()) {
+        qWarning() << "Src url size != targt url size";
+        return;
+    }
+
+    QString firsDestPath {targetList[0].path()};
+    static QRegularExpression reg("_dev_sr[0-9]*");
+    QRegularExpressionMatch match;
+    if (!firsDestPath.contains(reg, &match)) {
+        qWarning() << "Cannot map _dev_sr[0-9]";
+        return;
+    }
+    QString dev { match.captured().replace("_", "/")};
+    if (dev.isEmpty()) {
+        qWarning() << "Empty dev";
+        return;
+    }
+
+    QVariantMap map {DFMApplication::dataPersistence()->value("StagingMap", dev).toMap()};
+    for (int i = 0; i != srcList.size(); ++i)
+        map[targetList.at(i).path()] = srcList.at(i).path();
+
+    DFMApplication::dataPersistence()->setValue("StagingMap", dev, map);
+    DFMApplication::dataPersistence()->sync();
+}
