@@ -459,7 +459,7 @@ bool VaultController::deleteFiles(const QSharedPointer<DFMDeleteEvent> &event) c
 
     const_cast<VaultController *>(this)->setVauleCurrentPageMark(VaultPageMark::DELETEFILEPAGE);
     DUrlList urlList = vaultToLocalUrls(event->urlList());
-    bool bDeletedSuccess = DFileService::instance()->deleteFiles(event->sender(), urlList, true, event->silent());
+    bool bDeletedSuccess = DFileService::instance()->deleteFiles(event->sender(), urlList, false, event->silent());
     if (bDeletedSuccess) {
         const_cast<VaultController *>(this)->updateFileInfo(urlList);
     }
@@ -477,7 +477,7 @@ DUrlList VaultController::moveToTrash(const QSharedPointer<DFMMoveToTrashEvent>
     const_cast<VaultController *>(this)->slotFinishedCopyFileTotalSize();
     const_cast<VaultController *>(this)->setVauleCurrentPageMark(VaultPageMark::DELETEFILEPAGE);
     DUrlList urlList = vaultToLocalUrls(event->urlList());
-    bool bDeletedSuccess = DFileService::instance()->deleteFiles(event->sender(), urlList);
+    bool bDeletedSuccess = DFileService::instance()->deleteFiles(event->sender(), urlList, true, event->silent());
     if (bDeletedSuccess) {
         const_cast<VaultController *>(this)->updateFileInfo(urlList);
     }
@@ -665,6 +665,7 @@ void VaultController::updateFileInfo(const DUrlList &fileUrls)
                 fbi.isDir = fileInfo.isDir();
                 fbi.isFile = fileInfo.isFile();
                 fbi.isSymLink = fileInfo.isSymLink();
+                fbi.isWritable = true;
                 m_mapVaultFileInfo.insert(url, fbi);
             } else {
                 m_mapVaultFileInfo[url].isDir = fileInfo.isDir();
@@ -1141,15 +1142,11 @@ void VaultController::unlockVault(const DSecureString &password, QString lockBas
     } else {
         strPath = unlockFileDir;
     }
-    if (QFile::exists(strPath)) {   // 如果存在,则清空目录
+    if (QFile::exists(strPath)) {   // 如果存在
         QDir dir(strPath);
         if (!dir.isEmpty()) {
-            QDirIterator dirsIterator(strPath, QDir::AllEntries | QDir::NoDotAndDotDot);
-            while (dirsIterator.hasNext()) {
-                if (!dir.remove(dirsIterator.next())) {
-                    QDir(dirsIterator.filePath()).removeRecursively();
-                }
-            }
+            qWarning() << "Unlock vault failed, mount dir is not empty!";
+            return;
         }
     } else {   // 如果不存在,则创建目录
         QDir().mkpath(strPath);
