@@ -842,7 +842,14 @@ void DialogManager::showShareOptionsInPropertyDialog(const DFMUrlListBaseEvent &
     if (m_propertyDialogs.contains(url)) {
         PropertyDialog *dialog = m_propertyDialogs.value(url);
         if (dialog->expandGroup().count() > 1) {
+            dialog->expandGroup().at(0)->setAnimationDuration(0);
+            dialog->expandGroup().at(1)->setAnimationDuration(0);
+            dialog->expandGroup().at(0)->setExpand(false);
             dialog->expandGroup().at(1)->setExpand(true);
+            QTimer::singleShot(0, this, [=]() {
+                dialog->expandGroup().at(0)->setAnimationDuration(250);
+                dialog->expandGroup().at(1)->setAnimationDuration(250);
+            });
         }
     }
 }
@@ -995,6 +1002,21 @@ void DialogManager::showUserSharePasswordSettingDialog(quint64 winId)
     });
 }
 
+void DialogManager::showSharePasswordSettingDialog(QFrame *parent)
+{
+    if (!parent || parent->property("UserSharePwdSettingDialogShown").toBool()) {
+        return;
+    }
+    UserSharePasswordSettingDialog *dialog = new UserSharePasswordSettingDialog(parent);
+    dialog->show();
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
+    connect(dialog, &UserSharePasswordSettingDialog::finished, dialog, &UserSharePasswordSettingDialog::onButtonClicked);
+    parent->setProperty("UserSharePwdSettingDialogShown", true);
+    connect(dialog, &UserSharePasswordSettingDialog::closed, [=] {
+        parent->setProperty("UserSharePwdSettingDialogShown", false);
+    });
+}
+
 void DialogManager::showGlobalSettingsDialog(quint64 winId)
 {
     QWidget *w = WindowManager::getWindowById(winId);
@@ -1009,9 +1031,10 @@ void DialogManager::showGlobalSettingsDialog(quint64 winId)
 
     DSettingsDialog *dsd = new DFMSettingDialog(w);
     dsd->show();
-
+    w->setProperty("settingDialog", qlonglong(dsd));
     connect(dsd, &DSettingsDialog::finished, [ = ] {
         w->setProperty("isSettingDialogShown", false);
+        w->setProperty("settingDialog", 0);
     });
 }
 
@@ -1047,7 +1070,7 @@ void DialogManager::show4gFat32Dialog()
 void DialogManager::showFailToCreateSymlinkDialog(const QString &errorString)
 {
     DDialog d;
-    d.setTitle(tr("Fail to create symlink, cause:") + errorString);
+    d.setTitle(tr("Failed to create symlink, cause:") + errorString);
     d.setIcon(m_dialogWarningIcon);
     d.addButton(tr("OK","button"), true, DDialog::ButtonRecommend);
     d.exec();
@@ -1138,12 +1161,13 @@ void DialogManager::showFilePreviewDialog(const DUrlList &selectUrls, const DUrl
             m_urlList.clear();
         });
     } else {
+
         if (!m_filePreviewDialog) {
-            m_filePreviewDialog = new FilePreviewDialog(canPreivewlist, nullptr);
-            if (!DFMGlobal::isWayLand())
-                DPlatformWindowHandle::enableDXcbForWindow(m_filePreviewDialog, true);
+           m_filePreviewDialog = new FilePreviewDialog(canPreivewlist, nullptr);
+           if (!DFMGlobal::isWayLand())
+               DPlatformWindowHandle::enableDXcbForWindow(m_filePreviewDialog, true);
         } else {
-            m_filePreviewDialog->updatePreviewList(canPreivewlist);
+           m_filePreviewDialog->updatePreviewList(canPreivewlist);
         }
     }
 
@@ -1614,6 +1638,7 @@ int DialogManager::showPrivilegeDialog_SW(int nRet, const QString &srcfilename)
             return -1;
         }
     }
+    return -1;
 }
 
 #endif
