@@ -240,7 +240,7 @@ FilePreviewDialog::FilePreviewDialog(const DUrlList &previewUrllist, QWidget *pa
     : DAbstractDialog(parent), m_fileList(previewUrllist)
 {
 #ifdef Q_OS_LINUX
-#    ifndef ARCH_SW   // 申威和龙芯架构已禁用视频预览功能，不会触发此问题
+#    ifndef ARCH_SW   // SW与MIPS已禁用视频预览功能，不会触发此问题
 #        ifndef ARCH_MIPSEL   //
     // 先触发Qt多媒体库加载gstreamter插件
     // 因为预览视频时会先加载mpv库，如果之后再加载gst库，会导致崩溃在init_plugin
@@ -341,7 +341,7 @@ bool FilePreviewDialog::eventFilter(QObject *obj, QEvent *event)
 {
     if (event->type() == QEvent::KeyRelease) {
         const QKeyEvent *e = static_cast<QKeyEvent *>(event);
-        if(!e->isAutoRepeat()){
+        if (!e->isAutoRepeat()) {
             switch (e->key()) {
             case Qt::Key_Left:
             case Qt::Key_Up:
@@ -505,7 +505,6 @@ void FilePreviewDialog::switchToPage(int index)
                 return;
             }
         }
-
         if (!info->isDesktopFile())
             preview = DFMFilePreviewFactory::create(key);
 
@@ -519,10 +518,13 @@ void FilePreviewDialog::switchToPage(int index)
                 break;
             else if (preview->setFileUrl(m_fileList.at(index)))
                 break;
-            else
+            else {
                 preview->deleteLater();
+                preview = nullptr;
+            }
         }
     }
+
     if (!preview) {
         if (qobject_cast<UnknowFilePreview *>(m_preview)) {
             m_preview->setFileUrl(m_fileList.at(index));
@@ -542,15 +544,14 @@ void FilePreviewDialog::switchToPage(int index)
 
     if (m_preview) {
         m_preview->contentWidget()->setVisible(false);
-        m_preview->deleteLater();
         static_cast<QVBoxLayout *>(layout())->removeWidget(m_preview->contentWidget());
+        static_cast<QHBoxLayout *>(m_statusBar->layout())->removeWidget(m_preview->statusBarWidget());
+        m_preview->deleteLater();
+        m_preview = nullptr;
     }
 
     static_cast<QVBoxLayout *>(layout())->insertWidget(0, preview->contentWidget());
 
-    if (m_preview)
-        static_cast<QHBoxLayout *>(m_statusBar->layout())->removeWidget(m_preview->statusBarWidget());
-
     if (QWidget *w = preview->statusBarWidget())
         static_cast<QHBoxLayout *>(m_statusBar->layout())->insertWidget(3, w, 0, preview->statusBarWidgetAlignment());
 
@@ -602,9 +603,9 @@ void FilePreviewDialog::done(int r)
 
 void FilePreviewDialog::DoneCurrent()
 {
-//    if (this != nullptr && m_preview) {
-//        m_preview->DoneCurrent();
-//    }
+    //    if (this != nullptr && m_preview) {
+    //        m_preview->DoneCurrent();
+    //    }
 }
 
 void FilePreviewDialog::playCurrentPreviewFile()
