@@ -106,6 +106,7 @@ private:
         {"base.default_view.icon_size", DFMApplication::AA_IconSizeLevel},
         {"base.default_view.view_mode", DFMApplication::AA_ViewMode},
         {"base.default_view.view_size_adjustable", DFMApplication::AA_ViewSizeAdjustable},
+        {"base.default_view.mixed_sort", DFMApplication::AA_FileAndDirMixedSort},
     };
     BidirectionHash<QString, DFMApplication::GenericAttribute> keyToGA {
         {"base.hidden_files.show_hidden", DFMApplication::GA_ShowedHiddenFiles},
@@ -113,15 +114,14 @@ private:
         {"base.hidden_files.show_recent", DFMApplication::GA_ShowRecentFileEntry},
         {"advance.index.index_internal", DFMApplication::GA_IndexInternal},
         {"advance.index.index_external", DFMApplication::GA_IndexExternal},
-#ifdef FULLTEXTSEARCH_ENABLE
         {"advance.index.index_search", DFMApplication::GA_IndexFullTextSearch},
-#endif
         {"advance.search.show_hidden", DFMApplication::GA_ShowedHiddenOnSearch},
         {"advance.preview.compress_file_preview", DFMApplication::GA_PreviewCompressFile},
         {"advance.preview.text_file_preview", DFMApplication::GA_PreviewTextFile},
         {"advance.preview.document_file_preview", DFMApplication::GA_PreviewDocumentFile},
         {"advance.preview.image_file_preview", DFMApplication::GA_PreviewImage},
         {"advance.preview.video_file_preview", DFMApplication::GA_PreviewVideo},
+        {"advance.preview.audio_file_preview", DFMApplication::GA_PreviewAudio},
         {"advance.mount.auto_mount", DFMApplication::GA_AutoMount},
         {"advance.mount.auto_mount_and_open", DFMApplication::GA_AutoMountAndOpen},
         {"advance.mount.mtp_show_bottom_info", DFMApplication::GA_MTPShowBottomInfo},
