@@ -25,6 +25,7 @@
 
 #include <QFrame>
 #include <QTimer>
+#include <QPointer>
 
 #include "dabstractfileinfo.h"
 
@@ -32,15 +33,19 @@ QT_BEGIN_NAMESPACE
 class QComboBox;
 class QCheckBox;
 class QLineEdit;
+class QTextBrowser;
+class QPushButton;
 QT_END_NAMESPACE
 
 class ShareInfoFrame : public QFrame
 {
     Q_OBJECT
+    Q_PROPERTY(bool UserSharePwdSettingDialogShown READ getUserSharePwdSetDlgShow WRITE setUserSharePwdSetDlgShow)
 public:
     explicit ShareInfoFrame(const DAbstractFileInfoPointer &info, QWidget *parent = 0);
     ~ShareInfoFrame();
-
+    bool getUserSharePwdSetDlgShow() const;
+    void setUserSharePwdSetDlgShow(bool value);
     void initUI();
     void initConnect();
     void setFileinfo(const DAbstractFileInfoPointer &fileinfo);
@@ -49,7 +54,8 @@ public:
 signals:
     void folderShared(const QString &filePath);
     void unfolderShared();
-
+protected:
+    bool eventFilter(QObject *obj, QEvent *event) override;
 public slots:
     void handleCheckBoxChanged(const bool &checked);
     void handleShareNameFinished();
@@ -62,14 +68,31 @@ public slots:
     void updateShareInfo(const QString &filePath);
     void activateWidgets();
     void disactivateWidgets();
-
+private slots:
+    void setOrModifySharePassword();
+    void showShareInfo(bool value);
+    void updatePasswordState();
+private:
+    QString refreshIp() const;
 private:
     DAbstractFileInfoPointer m_fileinfo;
     QCheckBox *m_shareCheckBox = nullptr;
     QLineEdit *m_shareNamelineEdit = nullptr;
     QComboBox *m_permissoComBox = nullptr;
     QComboBox *m_anonymityCombox = nullptr;
+    QLabel *m_netScheme = nullptr;
+    QLineEdit *m_networkAddrLabel = nullptr;
+    QLineEdit *m_userNamelineEdit = nullptr;
+    QLineEdit *m_sharePasswordlineEdit = nullptr;
+    QPointer<QWidget> m_sharePropertyBkgWidget = nullptr;
+    QTextBrowser *m_shareNotes = nullptr;
+    QPushButton *splitLineGray = nullptr;
+    QPushButton *passwordOperation = nullptr;
+    bool m_isSharePasswordSet = false;
+    QTimer *m_refreshIp = nullptr;
     //QTimer *m_jobTimer;
+    QString m_selfIp;
+    bool m_userSharePwdSettingDialogShown = false;
 };
 
 #endif // SHAREINFOFRAME_H
