@@ -33,12 +33,16 @@
 
 #include "views/windowmanager.h"
 #include "shutil/fileutils.h"
+#include "../controllers/searchhistroymanager.h"
+#include "utils/utils.h"
+
 
 #include "gvfsmountmanager.h"
 
 #include <QProcess>
 #include <QRegularExpression>
 #include <QTimer>
+#include <QString>
 
 DFM_USE_NAMESPACE
 
@@ -107,7 +111,6 @@ QStringList NetworkManager::SupportScheme = {
 QMap<DUrl, NetworkNodeList> NetworkManager::NetworkNodes = {};
 GCancellable *NetworkManager::m_networks_fetching_cancellable = NULL;
 QPointer<QEventLoop> NetworkManager::eventLoop;
-
 NetworkManager::NetworkManager(QObject *parent) : QObject(parent)
 {
     qDebug() << "Create NetworkManager";
@@ -132,8 +135,28 @@ void NetworkManager::initConnect()
     connect(fileSignalManager, &FileSignalManager::requestFetchNetworks, this, &NetworkManager::fetchNetworks);
 }
 
+void NetworkManager::addSmbServerToHistory(const DUrl &url)
+{
+    //add search history list
+    SearchHistroyManager *historyManager = Singleton<SearchHistroyManager>::instance();
+    DUrl mountUrl = url;
+    QString toHistory;
+    QString scheme = mountUrl.scheme();
+    if(!scheme.isEmpty() && !mountUrl.host().isEmpty()){
+        toHistory = mountUrl.toString();
+        if (!historyManager->toStringList().contains(toHistory)) {//添加新历史挂载记录
+            historyManager->writeIntoSearchHistory(toHistory);
+        }else{//访问连接已经包含在历史记录中,先移除再追加到最后，用于下次打开对话框时显示上次连接。
+            historyManager->removeSearchHistory(toHistory);
+            historyManager->writeIntoSearchHistory(toHistory);
+        }
+    }
+}
+
 bool NetworkManager::fetch_networks(gchar *url, DFMEvent *e)
 {
+    if(isFetchingNetworks())
+        return false;
     QPointer<QEventLoop> oldEventLoop = eventLoop;
     QEventLoop event_loop;
 
@@ -159,6 +182,7 @@ bool NetworkManager::fetch_networks(gchar *url, DFMEvent *e)
                                         network_enumeration_finished,
                                         e);
         ret = eventLoop->exec();
+        e->setProperty("success",event_loop.property("success").toBool());
     } while (ret == EventLoopCode::MountFinished); // 需要重新执行 g_file_enumerate_children_async
 
     g_clear_object(&network_file);
@@ -178,20 +202,34 @@ void NetworkManager::network_enumeration_finished(GObject *source_object, GAsync
     enumerator = g_file_enumerate_children_finish(G_FILE(source_object), res, &error);
 
     qDebug() << "network_enumeration_finished";
-
+    if(eventLoop)
+        eventLoop->setProperty("success",false);
     if (error) {
         DFMUrlBaseEvent *event = static_cast<DFMUrlBaseEvent *>(user_data);
         if (!g_error_matches(error, G_IO_ERROR, G_IO_ERROR_CANCELLED) &&
                 !g_error_matches(error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED)) {
             qWarning("Failed to fetch network locations: %s", error->message);
+            //event->fileUrl() like:"smb://1.2.3.4/share_folder"
             if (event->fileUrl() == DUrl::fromNetworkFile("/")) {
                 NetworkManager::restartGVFSD();
             }
         }
         qDebug() << error->message;
+        QString test = event->fileUrl().toString();
         MountStatus status = gvfsMountManager->mount_sync(*event);
+        if(status == MountStatus::MOUNT_SUCCESS){
+            bool re = FileUtils::isSmbShareFolder(DUrl(test));
+            if(re){
+                RemoteMountsStashManager::insertStashedSmbDevice("smb://"+DUrl(test).host());//挂载成功后，添加smb聚合设备到配置中
+            }
+        }
         g_clear_error(&error);
+        if(status == MOUNT_SUCCESS){
+            if(eventLoop)
+                eventLoop->setProperty("success",true);
 
+            addSmbServerToHistory(event->fileUrl());
+        }
         if (eventLoop) {
             // 挂载完成时, 返回 1, 在fetch_networks中再次调用g_file_enumerate_children_async获取列表
             if (status == MOUNT_SUCCESS || status == MOUNT_PASSWORD_WRONG) {
@@ -230,7 +268,7 @@ void NetworkManager::network_enumeration_next_files_finished(GObject *source_obj
 
     if (error) {
         if (!g_error_matches(error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
-            qWarning("Failed to fetch network locations: %s", error->message);
+            qWarning("Failed to fetch network locations: %s", error->message);//指定的位置未挂载
             DFMEvent *event = static_cast<DFMEvent *>(user_data);
             if (event->fileUrl() == DUrl::fromNetworkFile("/")) {
                 NetworkManager::restartGVFSD();
@@ -238,12 +276,15 @@ void NetworkManager::network_enumeration_next_files_finished(GObject *source_obj
         }
         g_clear_error(&error);
     } else {
+        DFMUrlBaseEvent *event = static_cast<DFMUrlBaseEvent *>(user_data);
+        event->setProperty("isSuccess",true);
         populate_networks(G_FILE_ENUMERATOR(source_object), detected_networks, user_data);
 
         g_list_free_full(detected_networks, g_object_unref);
     }
 
     if (eventLoop) {
+        eventLoop->setProperty("success",error?false:true);
         eventLoop->exit(error ? EventLoopCode::FetchFailed : EventLoopCode::FetchFinished);
     }
 }
@@ -313,6 +354,8 @@ void NetworkManager::populate_networks(GFileEnumerator *enumerator, GList *detec
 
     NetworkNodes.remove(neturl);
     NetworkNodes.insert(neturl, nodeList);
+
+    addSmbServerToHistory(neturl);
     qDebug() << "request NetworkNodeList successfully";
 }
 
@@ -329,6 +372,15 @@ void NetworkManager::restartGVFSD()
     }
 }
 
+/**
+ * @brief NetworkManager::isFetchingNetworks 判断网络是否正在获取远程SMB目录列表
+ * @return
+ */
+bool NetworkManager::isFetchingNetworks()
+{
+    return eventLoop && eventLoop->isRunning();
+}
+
 void NetworkManager::fetchNetworks(const DFMUrlBaseEvent &event)
 {
     qDebug() << event;
@@ -361,6 +413,12 @@ void NetworkManager::fetchNetworks(const DFMUrlBaseEvent &event)
         gchar *url = const_cast<gchar *>(stdPath.c_str());
 
         if (fetch_networks(url, e)) {
+            bool re = FileUtils::isSmbHostOnly(e->fileUrl());
+            if(re){
+                RemoteMountsStashManager::insertStashedSmbDevice("smb://"+e->fileUrl().host());//当进行smb地址访问时，添加smb聚合设备到配置中
+                addSmbServerToHistory(e->fileUrl());//通知侧边栏和计算机界面显示smb挂载聚合项
+                emit addSmbMountIntegration(e->fileUrl());
+            }
             QWidget *main_window = WindowManager::getWindowById(e->windowId());
 
             // call later
@@ -379,6 +437,8 @@ void NetworkManager::fetchNetworks(const DFMUrlBaseEvent &event)
             });
         }
     }
+    if(!e->property("success").toBool())//挂载失败
+        emit mountFailed(fileUrl);
     delete e;
 }
 
