@@ -67,6 +67,11 @@
 #include "extensionimpl/dfmextmenuimpl.h"
 #include "extensionimpl/dfmextmendefine.h"
 #include "extensionimpl/private/dfmextmenuimpl_p.h"
+#include "utils/grouppolicy.h"
+
+#include <dgiomount.h>
+#include <dgiofile.h>
+#include <dgiovolumemanager.h>
 
 #include <DSysInfo>
 
@@ -87,9 +92,15 @@
 #include <unistd.h>
 
 
+#define DFM_MENU_ACTION_HIDDEN "dfm.menu.action.hidden"
+#define DD_MENU_ACTION_HIDDEN "dd.menu.action.hidden"
+#define DFD_MENU_ACTION_HIDDEB "dfd.menu.action.hidden"
+
 //fix:临时获取光盘刻录前临时的缓存地址路径，便于以后直接获取使用
 
+
 namespace DFileMenuData {
+static QHash<MenuAction, QString> actionPredicate;
 static QMap<MenuAction, QString> actionKeys;
 static QMap<MenuAction, QIcon> actionIcons;
 static QMap<MenuAction, QAction *> actions;
@@ -216,6 +227,36 @@ DFileMenu *DFileMenuManager::createNormalMenu(const DUrl &currentUrl, const DUrl
     DUrlList redirectedUrlList;
     if (urls.length() == 1) {
         QVector<MenuAction> actions = info->menuActionList(DAbstractFileInfo::SingleFile);
+        bool isSmbSharedDir = FileUtils::isSmbShareFolder(currentUrl);
+        if (isSmbSharedDir) {
+            bool isMounted = false;
+            for (auto gvfsmp : DGioVolumeManager::getMounts()) {//遍历当前挂载
+                auto rootFile = gvfsmp->getRootFile();
+                if (!rootFile)
+                    continue;
+
+                bool isSmb = FileUtils::isSmbPath(rootFile->path());
+                if(isSmb){
+                    DUrl mountUrl;
+                    QString shareName = FileUtils::smbAttribute(rootFile->path(),FileUtils::SmbAttribute::kShareName);
+                    QString shareHost = FileUtils::smbAttribute(rootFile->path(),FileUtils::SmbAttribute::kServer);
+                    QString name = currentUrl.path().toLower();//共享文件夹名称转小写
+                    QString host = currentUrl.host();
+                    if(name.startsWith("/"))
+                        name = name.mid(1);
+                    if(name == shareName && host == shareHost){
+                        isMounted =  true;
+                        break;
+                    }
+                }
+            }
+            if (isMounted) {//Menu show unmount item
+                actions << MenuAction::Unmount;
+            } else {//Menu show mount item
+                actions << MenuAction::Mount;
+            }
+            actions << MenuAction::Property;
+        }
         //修改在挂载的文件下面，不能删除，但是显示了删除
         //判定逻辑，如果是挂载盘，并且这个文件是对应的不是一个虚拟的项（表示有实体），那么这个文件就有彻底删除权限MenuAction::CompleteDeletion
         //但是这个文件canrename权限为false，以前的判断输出就是，不能MenuAction::Cut，MenuAction::Rename
@@ -574,9 +615,19 @@ DFileMenu *DFileMenuManager::createNormalMenu(const DUrl &currentUrl, const DUrl
     if(!VaultController::isVaultFile(currentUrl.toLocalFile())) {
         loadNormalPluginMenu(menu, urls, currentUrl, onDesktop);
     }
+    //把挂载、卸载、取消记住密码并卸载放到右键菜单的最后
+    QList<QAction*> acList = menu->actions();
+    QList<QAction*> lastList;
+    foreach(QAction* ac,acList){
+        if(ac->data() == MenuAction::Mount || ac->data() == MenuAction::Unmount || ac->data() == MenuAction::ForgetPassword){
+            lastList << ac;
+            acList.removeOne(ac);
+        }
+    }
+    if(!lastList.isEmpty())
+        menu->addActions(lastList);
     // stop loading Extension menus from json files
     //loadNormalExtensionMenu(menu, urlList, currentUrl);
-
     return menu;
 }
 
@@ -919,8 +970,50 @@ void DFileMenuData::initData()
         actionIcons[MenuAction::Property] = QIcon::fromTheme("document-properties");
     }
 
+    // fix #bug140633,原新建文本菜单项不支持icon，与产品和UI沟通，建文本菜单项新增icon且不纳入DGioSettings
+    actionIcons[MenuAction::NewText] = QIcon::fromTheme("text-plain");
+
     actionKeys[MenuAction::RemoveStashedRemoteConn] = QObject::tr("Remove");
+    actionKeys[MenuAction::UnmountAllSmbMount] = QObject::tr("Unmount");
     actionKeys[MenuAction::RefreshView] = QObject::tr("Refresh");
+    actionKeys[MenuAction::ForgetAllSmbPassword] = QObject::tr("Clear saved password and unmount");
+
+    // action predicate
+    actionPredicate[MenuAction::Open] =  "Open";
+    actionPredicate[MenuAction::OpenWith] =  "OpenWith";
+    actionPredicate[MenuAction::OpenFileLocation] =  "OpenFileLocation";
+    actionPredicate[MenuAction::StageFileForBurning] =  "StageFileForBurning";
+    actionPredicate[MenuAction::OpenInNewWindow] =  "OpenInNewWindow";
+    actionPredicate[MenuAction::OpenInNewTab] =  "OpenInNewTab";
+    actionPredicate[MenuAction::OpenAsAdmin] =  "OpenAsAdmin";
+    actionPredicate[MenuAction::Cut] = "Cut";
+    actionPredicate[MenuAction::Copy] = "Copy";
+    actionPredicate[MenuAction::Paste] = "Paste";
+    actionPredicate[MenuAction::SelectAll] = "SelectAll";
+    actionPredicate[MenuAction::Rename] = "Rename";
+    actionPredicate[MenuAction::Delete] = "Delete"; // 删除/移除/还原
+    actionPredicate[MenuAction::CompleteDeletion] = "CompleteDeletion";// 彻底删除
+    actionPredicate[MenuAction::ClearTrash] =  "ClearTrash";
+    actionPredicate[MenuAction::Restore] = "Restore";
+    actionPredicate[MenuAction::RestoreAll] = "RestoreAll";
+    actionPredicate[MenuAction::Mount] = "Mount";
+    actionPredicate[MenuAction::Share] = "Share";
+    actionPredicate[MenuAction::UnShare] = "UnShare";
+    actionPredicate[MenuAction::CreateSymlink] = "CreateSymlink";
+    actionPredicate[MenuAction::AddToBookMark] = "AddToBookMark";
+    actionPredicate[MenuAction::BookmarkRemove] = "BookmarkRemove";
+    actionPredicate[MenuAction::TagInfo] = "TagInfo";
+    actionPredicate[MenuAction::TagFilesUseColor] = "TagFilesUseColor";
+    actionPredicate[MenuAction::SendToDesktop] = "SendToDesktop";
+    actionPredicate[MenuAction::SendToRemovableDisk] = "SendToRemovableDisk"; // 发送到/发送到可移动磁盘
+    actionPredicate[MenuAction::SetAsWallpaper] =  "SetAsWallpaper";
+    actionPredicate[MenuAction::OpenInTerminal] = "OpenInTerminal";
+    actionPredicate[MenuAction::NewFolder] = "NewFolder";
+    actionPredicate[MenuAction::NewDocument] = "NewDocument";
+    actionPredicate[MenuAction::DisplayAs] =  "DisplayAs";
+    actionPredicate[MenuAction::SortBy] =  "SortBy";
+    actionPredicate[MenuAction::RefreshView] = "RefreshView";
+    actionPredicate[MenuAction::Property] = "Property";
 }
 
 void DFileMenuData::initActions()
@@ -967,6 +1060,10 @@ void DFileMenuData::initActions()
 
         QAction *action = new QAction(actionIcons.value(key), actionKeys.value(key), nullptr);
         action->setData(key);
+
+        if (actionPredicate.contains(key))
+            action->setProperty("predicate", actionPredicate.value(key));
+
         actions.insert(key, action);
         actionToMenuAction.insert(action, key);
     }
@@ -1006,6 +1103,15 @@ DFileMenu *DFileMenuManager::genereteMenuByKeys(const QVector<MenuAction> &keys,
         actions_initialized = true;
         DFileMenuData::initData();
         DFileMenuData::initActions();
+
+        // 菜单项策略若清空隐藏项后需要重置成显示
+        if (DTK_POLICY_SUPPORT)
+            connect(GroupPolicy::instance(), &GroupPolicy::valueChanged, [](const QString &key){
+                if (key == DFM_MENU_ACTION_HIDDEN || key == DD_MENU_ACTION_HIDDEN || key == DFD_MENU_ACTION_HIDDEB) {
+                    if (GroupPolicy::instance()->getValue(key).toList().isEmpty())
+                        DFileMenuManager::resetAllActionVisibility(true);
+                }
+            });
     }
 
     if (!isUseCachedAction) {
@@ -1056,6 +1162,7 @@ DFileMenu *DFileMenuManager::genereteMenuByKeys(const QVector<MenuAction> &keys,
             }
 
             tagAction->setData(key);
+            tagAction->setProperty("predicate", getActionPredicateByType(key));
             auto keyAction = DFileMenuData::actions.take(key);
             if (keyAction) {
                 QWidgetAction *widAction = dynamic_cast<QWidgetAction *>(keyAction);
@@ -1078,13 +1185,13 @@ DFileMenu *DFileMenuManager::genereteMenuByKeys(const QVector<MenuAction> &keys,
             if (!action) {
                 action = new QAction(DFileMenuData::actionKeys.value(key), nullptr);
                 action->setData(key);
+                action->setProperty("predicate", getActionPredicateByType(key));
                 DFileMenuData::actions[key] = action;
                 DFileMenuData::actionToMenuAction[action] = key;
             }
 
             action->setDisabled(disableList.contains(key));
             action->setProperty("_dfm_menu", QVariant::fromValue(menu));
-
             menu->addAction(action);
 
             if (!subMenuList.contains(key)) {
@@ -1109,6 +1216,9 @@ QString DFileMenuManager::getActionString(MenuAction type)
 //创建自定义菜单
 void DFileMenuManager::extendCustomMenu(DFileMenu *menu, bool isNormal, const DUrl &dir, const DUrl &focusFile, const DUrlList &selected, bool onDesktop)
 {
+    if (DFileMenuManager::menuHidden("extension-menu"))
+        return;
+
     if (!DFileMenuData::customMenuParser) {
         DFileMenuData::customMenuParser = new DCustomActionParser;
     }
@@ -1242,6 +1352,9 @@ void DFileMenuManager::extensionPluginCustomMenu(DFileMenu *menu,
                                                  const DUrlList &selected,
                                                  bool onDesktop)
 {
+    if (DFileMenuManager::menuHidden("extension-menu"))
+        return;
+
     if(!menu)
         return;
 
@@ -1372,6 +1485,7 @@ void DFileMenuManager::setActionString(MenuAction type, QString actionString)
 
     QAction *action = new QAction(actionString, nullptr);
     action->setData(type);
+    action->setProperty("predicate", getActionPredicateByType(type));
     DFileMenuData::actions.insert(type, action);
     DFileMenuData::actionToMenuAction[action] = type;
 }
@@ -1436,6 +1550,54 @@ void DFileMenuManager::clearActions()
     DFileMenuData::clearActions();
 }
 
+bool DFileMenuManager::menuHidden(const QString &scene)
+{
+    if (DTK_POLICY_SUPPORT) {
+        QVariant value = GroupPolicy::instance()->getValue(MENU_HIDDEN, "noSet");
+
+        if (value.toString() == "noSet")
+            return false;
+
+        auto menuHiddenLst = value.toStringList();
+        if (menuHiddenLst.isEmpty())
+            return false;
+        return menuHiddenLst.contains(scene);
+    } else {
+        return false;
+    }
+}
+
+void DFileMenuManager::menuFilterHiddenActions(QMenu *menu, const QString &scene)
+{
+    if (DTK_POLICY_SUPPORT) {
+        QVariant value = GroupPolicy::instance()->getValue(scene, "noSet");
+        if (value.toString() == "noSet")
+            return;
+
+        QStringList hiddenList =  value.toStringList();
+
+        if (hiddenList.isEmpty())
+            return;
+
+        auto actions = menu->actions();
+        for (QAction *temp : actions) {
+            if (hiddenList.contains(temp->property("predicate").toString()))
+                temp->setVisible(false);
+        }
+    }
+}
+
+QString DFileMenuManager::getActionPredicateByType(MenuAction type)
+{
+    return DFileMenuData::actionPredicate.value(type);
+}
+
+void DFileMenuManager::resetAllActionVisibility(bool visible)
+{
+    for(const auto temp : DFileMenuData::actions)
+        temp->setVisible(visible);
+}
+
 void DFileMenuManager::actionTriggered(QAction *action)
 {
     qDebug() << action << action->data().isValid();
