@@ -32,6 +32,7 @@
 
 #include "dfmsettings.h"
 #include "utils.h"
+#include "searchservice/searchservice.h"
 
 #include <QCoreApplication>
 #include <QMetaEnum>
@@ -45,6 +46,8 @@ Q_GLOBAL_STATIC_WITH_ARGS(DFMSettings, asGlobal, ("deepin/dde-file-manager/dde-f
 
 Q_GLOBAL_STATIC_WITH_ARGS(DFMSettings, gosGlobal, ("deepin/dde-file-manager.obtusely", DFMSettings::GenericConfig))
 Q_GLOBAL_STATIC_WITH_ARGS(DFMSettings, aosGlobal, ("deepin/dde-file-manager/dde-file-manager.obtusely", DFMSettings::GenericConfig))
+Q_GLOBAL_STATIC_WITH_ARGS(DFMSettings, dpGlobal, ("deepin/dde-file-manager/dde-file-manager.dp", DFMSettings::GenericConfig))
+
 //Q_GLOBAL_STATIC_WITH_ARGS(DFMSettings, aosGlobal, ("dde-file-manager.obtusely", DFMSettings::AppConfig))
 
 // blumia: since dde-desktop now also do show file selection dialog job, thus dde-desktop should share the same config file
@@ -90,6 +93,7 @@ void DFMApplicationPrivate::_q_onSettingsValueChanged(const QString &group, cons
         case DFMApplication::GA_PreviewImage:
         case DFMApplication::GA_PreviewTextFile:
         case DFMApplication::GA_PreviewVideo:
+        case DFMApplication::GA_PreviewAudio:
             Q_EMIT self->previewAttributeChanged(ga, value.toBool());
             break;
         case DFMApplication::GA_ShowedHiddenFiles:
@@ -109,16 +113,22 @@ void DFMApplicationPrivate::_q_onSettingsValueChanged(const QString &group, cons
             break;
         case DFMApplication::GA_AlwaysShowOfflineRemoteConnections:
             gsGlobal->sync(); // cause later invocations may update the config file, so sync the config before.
+            //smb挂载聚合功能实现后，这里无需刷新计算机界面以及调用stashCurrentMounts();
+            //因为现在smb挂载项是否常驻的区别在于：最后一个挂载项移除之后，是否移除smb聚合项
             if (value.toBool()) { // stash all mounted remote connections
-                RemoteMountsStashManager::stashCurrentMounts();
+            //RemoteMountsStashManager::stashCurrentMounts();
             } else { // remove all stashed remote connections
                 RemoteMountsStashManager::clearRemoteMounts();
             }
-            Q_EMIT self->reloadComputerModel();
+            //Q_EMIT self->reloadComputerModel();
             break;
         case DFMApplication::GA_HideLoopPartitions:
             Q_EMIT self->reloadComputerModel();
             break;
+        case DFMApplication::GA_IndexFullTextSearch:
+            if (value.toBool() && qAppName() == "dde-file-manager")
+                searchServ->createFullTextIndex();
+            break;
         default:
             break;
         }
@@ -317,6 +327,18 @@ DFMSettings *DFMApplication::appObtuselySetting()
     return aosGlobal;
 }
 
+DFMSettings *DFMApplication::dataPersistence()
+{
+    if (!dpGlobal.exists()) {
+        dpGlobal->setAutoSync(true);
+#ifndef DFM_NO_FILE_WATCHER
+        dpGlobal->setWatchChanges(true);
+#endif
+    }
+
+    return dpGlobal;
+}
+
 DFMApplication::DFMApplication(DFMApplicationPrivate *dd, QObject *parent)
     : QObject(parent)
     , d_ptr(dd)
