@@ -48,7 +48,8 @@ public:
         AA_OpenFileMode, // 点击/双击[0/1]
         AA_UrlOfNewWindow, // 新窗口默认路径
         AA_UrlOfNewTab, // 新标签页默认路径
-        AA_ThemeName
+        AA_ThemeName,
+        AA_FileAndDirMixedSort  // 普通文件与目录混合排序
     };
 
     Q_ENUM(ApplicationAttribute)
@@ -63,6 +64,7 @@ public:
         GA_PreviewDocumentFile, // 文档生成缩略图（pdf）
         GA_PreviewImage, // 图片生成缩略图
         GA_PreviewVideo, // 文件生成缩略图
+        GA_PreviewAudio,
         GA_AutoMount, // 自动挂载硬盘设备
         GA_AutoMountAndOpen, // 自动挂载并打开硬盘设备
         GA_MTPShowBottomInfo, // mtp 挂载时显示底部数据统计
@@ -101,6 +103,7 @@ public:
 
     static DFMSettings *genericObtuselySetting();
     static DFMSettings *appObtuselySetting();
+    static DFMSettings *dataPersistence();
 
 Q_SIGNALS:
     void appAttributeChanged(ApplicationAttribute aa, const QVariant &value);
