@@ -47,7 +47,7 @@
 
 // begin file item global define
 #define TEXT_LINE_HEIGHT 18
-#define MAX_THREAD_COUNT 1000
+#define MAX_THREAD_COUNT 100
 #define MAX_FILE_NAME_CHAR_COUNT 255
 #define DDE_TRASH_ID "dde-trash"
 #define DDE_COMPUTER_ID "dde-computer"
@@ -202,6 +202,8 @@ public:
         CompleteDeletion,
         Mount,
         Unmount,
+        UnmountAllSmbMount,
+        ForgetAllSmbPassword,
         Eject,
         SafelyRemoveDrive,
         Name,
@@ -317,6 +319,7 @@ public:
     static void initBluetoothManager();
     static void initRootFileManager();
     static void initEmblemPluginManagerConnection();
+    static void initVaultDbusResponse();
 
     static QString getUser();
     static int getUserId();
