@@ -25,6 +25,7 @@
 #include "views/dfmopticalmediawidget.h"
 #include "gvfs/gvfsmountmanager.h"
 
+#include "dfmapplication.h"
 #include "singleton.h"
 #include "dblockdevice.h"
 #include "ddiskdevice.h"
@@ -44,6 +45,7 @@
 #include "shutil/fileutils.h"
 #include "vault/vaulthelper.h"
 #include "computermodel.h"
+#include "utils.h"
 
 #include <QtConcurrent>
 
@@ -79,12 +81,31 @@ ComputerModel::ComputerModel(QObject *parent)
                 if (chi->scheme() == DFMROOT_SCHEME && chi->suffix() == SUFFIX_USRDIR) {
                     addItem(chi->fileUrl());
                 } else {
+                    //跳过smb挂载或缓存项，后面单独创建聚合项
+                    QString smbIp;
+                    FileUtils::isSmbRelatedUrl(chi->fileUrl(),smbIp);
+                    if (!smbIp.isEmpty()){
+                        if(chi->fileUrl().toString().endsWith( QString(".%1").arg(SUFFIX_GVFSMP)) && FileUtils::isNetworkUrlMounted( chi->fileUrl() )){
+                            continue;
+                        }
+                        if(chi->fileUrl().toString().endsWith( QString(".%1").arg(SUFFIX_STASHED_REMOTE))){
+                            continue;
+                        }
+                    }
+
                     addRootItem(chi);
                     if (chi->fileUrl().path().contains("sr"))
                         opticalchanged = true;
                 }
             }
 
+            //最后添加smb聚合设备
+            QStringList m_smbDevices = RemoteMountsStashManager::stashedSmbDevices();
+            foreach(const QString &smbDevice, m_smbDevices){
+                DAbstractFileInfoPointer fi = fileService->createFileInfo(this, DUrl(smbDevice));
+                addRootItem(fi);
+            }
+
             if (!m_isQueryRootFileFinshed) {
                 // 获取完根目录信息后刷新光驱信息，用于区分内外置光驱。
                 if (opticalchanged) {
@@ -92,6 +113,7 @@ ComputerModel::ComputerModel(QObject *parent)
                 }
                 m_isQueryRootFileFinshed = true;
             }
+
         };
 
         connect(DRootFileManager::instance(),&DRootFileManager::queryRootFileFinsh,this,[this,rootInit](){
@@ -172,6 +194,20 @@ ComputerModel::ComputerModel(QObject *parent)
         m_watcher = DRootFileManager::instance()->rootFileWather();
         connect(m_watcher, &DAbstractFileWatcher::fileDeleted, this, &ComputerModel::removeItem);
         connect(m_watcher, &DAbstractFileWatcher::subfileCreated, this, [this, addComputerItem](const DUrl &url) {
+            QString smbIp;
+            FileUtils::isSmbRelatedUrl(url,smbIp);
+            if (!smbIp.isEmpty()){
+                DUrl smbDevice(QString("%1://%2").arg(SMB_SCHEME).arg(smbIp));
+                if(isSmbItemExisted(smbDevice))//smb device is already added
+                    return;
+                else{
+                    //DAbstractFileInfoPointer fi = fileService->createFileInfo(this, DUrl(url));//如果url的scheme是smb，则使用的是NetworkController::createFileInfo
+                    //addRootItem(fi);
+                    addComputerItem(smbDevice);
+                    return;
+                }
+            }
+
             addComputerItem(url);
             if (url.path().contains("sr"))
                 emit opticalChanged();
@@ -282,7 +318,6 @@ QVariant ComputerModel::data(const QModelIndex &index, int role) const
 
     if (role == Qt::DecorationRole) {
         if (pitmdata->fi) {
-
             DFMRootFileInfo::ItemType itemType = static_cast<DFMRootFileInfo::ItemType>(pitmdata->fi->fileType());
             if (itemType == DFMRootFileInfo::UDisksOptical) {
                 QString udisk = pitmdata->fi->extraProperties()["udisksblk"].toString();
@@ -294,7 +329,9 @@ QVariant ComputerModel::data(const QModelIndex &index, int role) const
                     return QIcon::fromTheme("media-external");
                 }
             }
-
+            if(pitmdata->url.scheme() == SMB_SCHEME){
+                return QIcon::fromTheme("folder-remote");
+            }
             return QIcon::fromTheme(pitmdata->fi->iconName());
         }
     }
@@ -389,7 +426,15 @@ QVariant ComputerModel::data(const QModelIndex &index, int role) const
 
     if (role == DataRoles::ActionVectorRole) {
         if (pitmdata->fi) {
-            return QVariant::fromValue(pitmdata->fi->menuActionList());
+            QVector<MenuAction> av = pitmdata->fi->menuActionList();
+            QString scheme = index.data(ComputerModel::DataRoles::SchemeRole).toString();
+            if(scheme == SMB_SCHEME){
+                av.clear();
+                av.append(MenuAction::UnmountAllSmbMount);
+                av.append(MenuAction::ForgetAllSmbPassword);
+                av.append(MenuAction::OpenDisk);
+            }
+            return QVariant::fromValue(av);
         }
     }
 
@@ -689,6 +734,12 @@ void ComputerModel::onOpticalChanged()
     thread.detach();
 }
 
+bool ComputerModel::isSmbItemExisted(const DUrl &smbDevice)
+{
+    int index = findItem(smbDevice);
+    return index >=0;
+}
+
 void ComputerModel::getRootFile()
 {
     QList<DAbstractFileInfoPointer> ch = rootFileManager->getRootFile();
@@ -726,7 +777,6 @@ void ComputerModel::addRootItem(const DAbstractFileInfoPointer &info)
         return;
     if (!Singleton<PathManager>::instance()->isVisiblePartitionPath(info))
         return;
-
 #ifdef SPLIT_APP_ENTRY
     auto splitterUrl = info->scheme() == DFMROOT_SCHEME
             ? makeSplitterUrl(Disks)
@@ -747,7 +797,7 @@ void ComputerModel::addRootItem(const DAbstractFileInfoPointer &info)
                                   [](const DAbstractFileInfoPointer &a, const ComputerModelItemData &b) {
             return DFMRootFileInfo::typeCompare(a, b.fi);
         });
-        if (r == m_items.end()) {
+        if (r == m_items.end()  || info->scheme() == SMB_SCHEME) {
             addItem(info->fileUrl());
         } else {
             insertBefore(info->fileUrl(), r->url);
@@ -787,7 +837,8 @@ void ComputerModel::initItemData(ComputerModelItemData &data, const DUrl &url, Q
         data.widget = w;
     } else {
         //这里不用去创建fileinfo，已经缓存了rootfileinfo //get root file info cache
-        if (url.toString().endsWith(SUFFIX_GVFSMP))
+//        if (url.toString().endsWith(SUFFIX_GVFSMP))
+        if (url.toString().startsWith("smb://"))
         {
             const DAbstractFileInfoPointer &info = DRootFileManager::getFileInfo(url);
             if (info) {
@@ -805,6 +856,7 @@ void ComputerModel::initItemData(ComputerModelItemData &data, const DUrl &url, Q
             data.cat = ComputerModelItemData::Category::cat_user_directory;
         } else {
             data.cat = ComputerModelItemData::Category::cat_internal_storage;
+
         }
     }
 }
