@@ -133,7 +133,7 @@ ComputerView::ComputerView(QWidget *parent) : QWidget(parent)
     setLayout(new QVBoxLayout);
     layout()->addWidget(m_view);
     layout()->addWidget(m_statusbar);
-    layout()->setMargin(0);
+    layout()->setContentsMargins(10, 0, 0, 0);
 
     m_model = new ComputerModel(this);
     m_view->setModel(m_model);
@@ -197,7 +197,24 @@ ComputerView::ComputerView(QWidget *parent) : QWidget(parent)
                 return;
             }
         }
-
+        //!点击计算机页面中的SMB设备时，如果是SMB设备，则进入smb://<host>目录
+        //! dfmroot:///smb://<host>/<share_folder>.remote
+        //! dfmroot:///smb://xxxxxxxxxxxxxxxxxx.gvfsmp
+        QString localFilePath = QUrl::fromPercentEncoding(url.path().toLocal8Bit());
+        localFilePath = localFilePath.startsWith("//") ? localFilePath.mid(1) : localFilePath;
+        bool isGvfsFile = FileUtils::isGvfsMountFile(localFilePath);
+        if(isGvfsFile || FileUtils::isSmbShareFolder(url)){
+            QString smbIp;
+            bool re = FileUtils::isSmbRelatedUrl(url,smbIp);
+            if (re) {
+                QWidget *p = WindowManager::getWindowById(window()->internalWinId());
+                if (p) {
+                    DUrl temUrl(QString("%1://%2").arg(SMB_SCHEME).arg(smbIp));
+                    DFMEventDispatcher::instance()->processEvent<DFMChangeCurrentUrlEvent>(this, temUrl, p);
+                    return;
+                }
+            }
+        }
         // searchBarTextEntered also invoke "checkGvfsMountFileBusy", forbit invoke twice
         if (url.path().endsWith(SUFFIX_STASHED_REMOTE)) {
             DFileManagerWindow *window = qobject_cast<DFileManagerWindow *>(this->window());
@@ -278,6 +295,9 @@ ComputerView::ComputerView(QWidget *parent) : QWidget(parent)
         {
             const QModelIndex &idx = m_view->selectionModel()->currentIndex();
             DUrl url = idx.data(ComputerModel::DataRoles::DFMRootUrlRole).value<DUrl>();
+            if (url.scheme() == APPENTRY_SCHEME)
+                return; // no property for appentry item.
+
             if (url.path().endsWith(SUFFIX_USRDIR)) {
                 appController->actionProperty(dMakeEventPointer<DFMUrlListBaseEvent>(this, DUrlList() << idx.data(ComputerModel::DataRoles::OpenUrlRole).value<DUrl>()));
             } else {
@@ -383,7 +403,15 @@ void ComputerView::contextMenu(const QPoint &pos)
         quint64 wndId = WindowManager::getWindowId(this);
         menu = DFileMenuManager::createVaultMenu(WindowManager::getWindowById(wndId));
     } else {
-        menu = DFileMenuManager::genereteMenuByKeys(av, disabled);
+        const QString &scheme = idx.data(ComputerModel::DataRoles::SchemeRole).value<QString>();
+        if(scheme == SMB_SCHEME){
+            QVector<MenuAction> actionValue;
+            actionValue << MenuAction::UnmountAllSmbMount
+                        << MenuAction::ForgetAllSmbPassword;
+            menu = DFileMenuManager::genereteMenuByKeys(actionValue, disabled);
+        }else{
+            menu = DFileMenuManager::genereteMenuByKeys(av, disabled);
+        }
     }
 
     menu->setEventData(DUrl(), {idx.data(ComputerModel::DataRoles::DFMRootUrlRole).value<DUrl>()}, WindowManager::getWindowId(this), this);
