@@ -373,11 +373,16 @@ bool DFileManagerWindowPrivate::cdForTab(Tab *tab, const DUrl &fileUrl)
             bool ret = view->setRootUrl(realUrl);
             delete view;
             view = nullptr;
-            return ret;
+            if (!ret)
+                return ret;
         }
     }
 
     if (!current_view || !DFMViewManager::instance()->isSuited(fileUrl, current_view)) {
+        DFileView *fv = dynamic_cast<DFileView *>(currentView);
+        if (fv)
+            fv->cancelDrag();
+
         DFMBaseView *view = DFMViewManager::instance()->createViewByUrl(fileUrl);
         if (view) {
             viewStackLayout->addWidget(view->widget());
@@ -1190,7 +1195,7 @@ void DFileManagerWindow::initUI()
     D_DC(DFileManagerWindow);
 
     resize(DEFAULT_WINDOWS_WIDTH, DEFAULT_WINDOWS_HEIGHT);
-    setMinimumSize(760, 420);
+    setMinimumSize(680, 300);   // ui需求
     initTitleBar();
     initCentralWidget();
     setCentralWidget(d->centralWidget);
@@ -1492,7 +1497,9 @@ void DFileManagerWindow::initConnect()
             if (d->currentView && d->currentView->widget()) {
                 QSize variable(1, 1);
                 d->currentView->widget()->resize(d->currentView->widget()->size() - variable);
-                d->currentView->widget()->resize(d->currentView->widget()->size() + variable);
+                QTimer::singleShot(0,this,[=](){
+                    d->currentView->widget()->resize(d->currentView->widget()->size() + variable);
+                });
             }
             qDebug() << "File information window on the right";
         }
