@@ -448,7 +448,7 @@ Qt::DropAction DFMSideBarView::canDropMimeData(DFMSideBarItem *item, const QMime
         //防止不可添加tag的文件被拖进tag目录从而获取tag属性
         if (item->url().isTaggedFile() && !fileInfo->canTag()) {
             return Qt::IgnoreAction;
-        }        
+        }
     }
 
     if (!info || !info->canDrop()) {
@@ -590,7 +590,7 @@ bool DFMSideBarView::fetchDragEventUrlsFromSharedMemory()
 bool DFMSideBarView::checkOpTime()
 {
     //如果两次操作时间间隔足够长，则返回true
-    if (QDateTime::currentDateTime().toMSecsSinceEpoch() - m_lastOpTime > 200) {
+    if (abs(QDateTime::currentDateTime().toMSecsSinceEpoch() - m_lastOpTime) > 200) {
         m_lastOpTime = QDateTime::currentDateTime().toMSecsSinceEpoch();
         return true;
     }
