@@ -34,7 +34,7 @@
 #include "dfmevent.h"
 #include "app/define.h"
 #include "app/filesignalmanager.h"
-
+#include "shutil/fileutils.h"
 #include "dfilemenumanager.h"
 
 #include "singleton.h"
@@ -264,6 +264,8 @@ void DToolBar::searchBarTextEntered(const QString textEntered)
 {
     QString text = textEntered;
 
+    if(text.endsWith("/"))
+        text.chop(1);
     if (text.isEmpty()) {
         //m_searchBar->clearText();
         return;
@@ -335,6 +337,8 @@ void DToolBar::currentUrlChanged(const DFMEvent &event)
 void DToolBar::back()
 {
     DUrl url = m_navStack->back();
+    if(FileUtils::isSmbShareFolder(url))//从smb://x.x.x.x/share_folder返回到smb://x.x.x.x
+        url.setPath("");
     //判断网络文件是否可以到达
     if (DFileService::instance()->checkGvfsMountfileBusy(url)) {
         return;
@@ -552,5 +556,7 @@ void DToolBar::setEnterText(QString &text)
         text = "usershare:///";
     } else if (text.startsWith("computer:")) {
         text = "computer:///";
+    } else if (text.startsWith("trash:")) {
+        text = "trash:///"; //fix bug: 141489
     }
 }
