@@ -9,7 +9,7 @@
     <message>
         <location filename="../main.cpp" line="195"/>
         <source>File Manager is a powerful and easy-to-use file management tool, featured with searching, copying, trash, compression/decompression, file property and other useful functions.</source>
-        <translation>《檔案管理器》是個強大且易用的檔案管理工具，有搜尋、複製、垃圾桶功能、壓縮／解壓縮、檔案屬性等實用功能。</translation>
+        <translation>檔案管理器是個強大且易用的文件管理工具，有搜尋、複製、垃圾桶功能、壓縮／解壓縮、文件屬性等實用功能。</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
